import * as i0 from '@angular/core';
import { Injectable, NgModule } from '@angular/core';
import { __awaiter } from 'tslib';

class FormbirdInjectorService {
    constructor() {
        // get the injector. If running with an AngularJS core the injector will be the AngularJS injector. If running with an
        // Angular core, the injector is exposed globally in a window.FormbirdServiceInjector object. Once we have moved all customers
        // to an Angular core, we can remove the searching for an AngularJS injector
        // first try getting the global formbird service injector which will be defined if running with an Angular only core
        this.injector = window.FormbirdServiceInjector;
        // if injector is not defined, get the AngularJS injector, this will happen if running with an AngularJS core
        if (!this.injector) {
            const element = document.querySelectorAll('#bodyAngularJS div[ui-view]');
            this.injector = angular.element(element).injector();
            this.isAngularJS = true;
        }
    }
    get(serviceName) {
        // first try getting the global formbird service injector which will be defined if running with an Angular only core
        return this.injector.get(serviceName);
    }
    isAngularJSCore() {
        return this.isAngularJS;
    }
}
FormbirdInjectorService.ɵfac = function FormbirdInjectorService_Factory(t) { return new (t || FormbirdInjectorService)(); };
FormbirdInjectorService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: FormbirdInjectorService, factory: FormbirdInjectorService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(FormbirdInjectorService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

class SearchService {
    constructor(formbirdInjectorService) {
        this.formbirdInjectorService = formbirdInjectorService;
        this.searchService = formbirdInjectorService.get('SearchService');
    }
    /**
     * Do Elastic search on server side. If the browser is offline, do searching indexedDB.
     * @param options consists of text, filter query to search
     * @param searchContext an object consists of additional params
     * @returns Promise
     */
    search(options, searchContext) {
        return this.searchService.search(options, searchContext);
    }
    generatePit() {
        return this.searchService.generatePit().toPromise();
    }
}
SearchService.ɵfac = function SearchService_Factory(t) { return new (t || SearchService)(i0.ɵɵinject(FormbirdInjectorService)); };
SearchService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: SearchService, factory: SearchService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(SearchService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class ConfigService {
    constructor() { }
    clientConfig() {
        return window['ftClientConfig'];
    }
}
ConfigService.ɵfac = function ConfigService_Factory(t) { return new (t || ConfigService)(); };
ConfigService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ConfigService, factory: ConfigService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ConfigService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

class ModifiedFieldService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('ModifiedFieldService');
    }
    /**
     * Reset the current form to its un-interacted state.
     */
    resetFormDirty() {
        this.ajsService.resetFormDirty();
    }
    /**
     * Check if the current form is dirty, that make the save button appear and blink or display unsaved changes dialog
     */
    isDirty() {
        return this.ajsService.isDirty();
    }
    /*
     * This method is used to add modified field by document id.
     * Before adding should check whether the version of the document has changed from the original because
     * there is a case reset current document from the one returned from server once it is saved.
     * @returns: true if adding successfully, otherwise: false
     */
    addModifiedField(documentId, changedFieldName, documentListId, shouldCompareDocuments, overrideTemplateId) {
        return this.ajsService.addModifiedField(documentId, changedFieldName, documentListId, shouldCompareDocuments, overrideTemplateId);
    }
}
ModifiedFieldService.ɵfac = function ModifiedFieldService_Factory(t) { return new (t || ModifiedFieldService)(i0.ɵɵinject(FormbirdInjectorService)); };
ModifiedFieldService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ModifiedFieldService, factory: ModifiedFieldService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ModifiedFieldService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class UnsavedDocumentService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('UnsavedDocumentService');
    }
    setDocument(unsavedDocumentListId, document) {
        return this.ajsService.setDocument(unsavedDocumentListId, document);
    }
    setTemplate(unsavedDocumentListId, documentId, template) {
        return this.ajsService.setTemplate(unsavedDocumentListId, documentId, template);
    }
    removeDocumentList(unsavedDocumentListId) {
        return this.ajsService.removeDocumentList(unsavedDocumentListId);
    }
    /**
     * create a new unsaved document list. The unsaved document list is a list of documents that will be saved in a single
     * operation. This allows saving of documents independently of the nav bar save button. Eg. If you open up a dialog with a
     * template with a child doc then you need to save several documents on dialog close without saving the main document loaded
     * in the form. We can't put parameters in the save function to handle special cases like whether the save is for a dialog
     * because we would have to keep adding more special cases for saving from different locations.
     */
    createUnsavedDocumentList(name, existingUnsavedDocumentListId) {
        return this.ajsService.createUnsavedDocumentList(name, existingUnsavedDocumentListId);
    }
    updateDocumentListInfo(documentInfo, unsavedDocumentListId) {
        this.ajsService.updateDocumentListInfo(documentInfo, unsavedDocumentListId);
    }
}
UnsavedDocumentService.ɵfac = function UnsavedDocumentService_Factory(t) { return new (t || UnsavedDocumentService)(i0.ɵɵinject(FormbirdInjectorService)); };
UnsavedDocumentService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: UnsavedDocumentService, factory: UnsavedDocumentService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(UnsavedDocumentService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class ClientRulesService {
    constructor(injector) {
        this.injector = injector;
        this.ajsClientRulesService = injector.get('ClientRulesService');
    }
    getSharedValue(key) {
        return this.ajsClientRulesService.getSharedValue(key);
    }
    setSharedValue(key, value) {
        return this.ajsClientRulesService.setSharedValue(key, value);
    }
}
ClientRulesService.ɵfac = function ClientRulesService_Factory(t) { return new (t || ClientRulesService)(i0.ɵɵinject(FormbirdInjectorService)); };
ClientRulesService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ClientRulesService, factory: ClientRulesService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ClientRulesService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class OfflineUtilService {
    constructor(formbirdInjectorService) {
        this.formbirdInjectorService = formbirdInjectorService;
        this.ajsService = formbirdInjectorService.get('OfflineUtilService');
    }
    getNextId() {
        return this.ajsService.getNextId();
    }
}
OfflineUtilService.ɵfac = function OfflineUtilService_Factory(t) { return new (t || OfflineUtilService)(i0.ɵɵinject(FormbirdInjectorService)); };
OfflineUtilService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: OfflineUtilService, factory: OfflineUtilService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(OfflineUtilService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class BroadcastService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('BroadcastService');
        this.rebroadcastAngularJSEvents();
    }
    /**
     * rebroadcast AngularJS events as observables so that Angular components can subscribe to them
     */
    rebroadcastAngularJSEvents() {
        if (typeof angular !== 'undefined') {
            const element = document.querySelectorAll('div[ui-view]');
            const injector = angular.element(element).injector();
            // rebroadcast AngularJS broadcasts as observables so that Angular subscribers can get the message
            if (injector) {
                const rootScope = injector.get('$rootScope');
                rootScope.$on('document:updated', (event, data) => {
                    this.broadcast('document:updated', data);
                });
            }
        }
    }
    broadcast(key, data) {
        if (!this.ajsService) {
            console.log('No BroadcastService provided.');
        }
        else {
            this.ajsService.broadcast(key, data);
        }
    }
    on(key) {
        if (!this.ajsService) {
            console.log('No BroadcastService provided.');
        }
        else {
            return this.ajsService.on(key);
        }
    }
}
BroadcastService.ɵfac = function BroadcastService_Factory(t) { return new (t || BroadcastService)(i0.ɵɵinject(FormbirdInjectorService)); };
BroadcastService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: BroadcastService, factory: BroadcastService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BroadcastService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class NotificationService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('NotificationService');
    }
    /**
     * Display toast messages
     */
    printMessage(message, messageType, title, position, preventDuplicate, displayDesktopNotification, onClickFunction, timeOut, isPermanent) {
        return this.ajsService.printMessage(message, messageType, title, position, preventDuplicate, displayDesktopNotification, onClickFunction, timeOut, isPermanent);
    }
    success(message, title, displayDesktopNotification) {
        return this.ajsService.success(message, title, displayDesktopNotification);
    }
    error(message, title, displayDesktopNotification) {
        return this.ajsService.error(message, title, displayDesktopNotification);
    }
    warning(message, title, displayDesktopNotification) {
        return this.ajsService.warning(message, title, displayDesktopNotification);
    }
}
NotificationService.ɵfac = function NotificationService_Factory(t) { return new (t || NotificationService)(i0.ɵɵinject(FormbirdInjectorService)); };
NotificationService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: NotificationService, factory: NotificationService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(NotificationService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class LocationService {
    constructor() {
        if (window.angular) {
            const element = document.querySelectorAll('div[ui-view]');
            const injector = angular.element(element).injector();
            this.ajsService = injector.get('$location');
        }
    }
    /**
     * go to URL. This will need to call the Angular 2+ Location.go when upgraded
     */
    go(path) {
        return this.ajsService.path(path);
    }
}
LocationService.ɵfac = function LocationService_Factory(t) { return new (t || LocationService)(); };
LocationService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: LocationService, factory: LocationService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(LocationService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

class ModalService {
    constructor(formbirdInjectorService) {
        this.formbirdInjectorService = formbirdInjectorService;
        this.ajsService = formbirdInjectorService.get('ModalService');
    }
    showDialog(message, errorType, succFunc, errorFunc, discardFunc) {
        this.ajsService.showDialog(message, errorType, succFunc, errorFunc, discardFunc);
    }
    openDialog(options) {
        this.ajsService.openDialog(options);
    }
}
ModalService.ɵfac = function ModalService_Factory(t) { return new (t || ModalService)(i0.ɵɵinject(FormbirdInjectorService)); };
ModalService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ModalService, factory: ModalService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ModalService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class DocumentListService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('DocumentListService');
    }
    setupDocumentListId() {
        return this.ajsService.setupDocumentListId();
    }
    save() {
        return this.ajsService.save();
    }
    clearDocuments(documentListId) {
        this.ajsService.clearDocuments(documentListId);
    }
}
DocumentListService.ɵfac = function DocumentListService_Factory(t) { return new (t || DocumentListService)(i0.ɵɵinject(FormbirdInjectorService)); };
DocumentListService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: DocumentListService, factory: DocumentListService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(DocumentListService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class ValidationService {
    constructor(injector) {
        this.injector = injector;
        this.validationCtrlValues = {};
        this.ajsService = injector.get('ValidationService');
        this.validationCtrlValues = this.ajsService.validationCtrlValues;
    }
    loadValidators(componentDef, fieldName) {
        return this.ajsService.loadValidators(componentDef, fieldName);
    }
}
ValidationService.ɵfac = function ValidationService_Factory(t) { return new (t || ValidationService)(i0.ɵɵinject(FormbirdInjectorService)); };
ValidationService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ValidationService, factory: ValidationService.ɵfac });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ValidationService, [{
            type: Injectable
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class WebSocketService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('WebSocketService');
    }
    emit(eventName, data) {
        return this.ajsService.emit(eventName, data);
    }
    addEventListener(eventName, eventHandlerFunc) {
        return this.ajsService.addEventListener(eventName, eventHandlerFunc);
    }
    removeEventListener(eventName) {
        return this.ajsService.removeEventListener(eventName);
    }
}
WebSocketService.ɵfac = function WebSocketService_Factory(t) { return new (t || WebSocketService)(i0.ɵɵinject(FormbirdInjectorService)); };
WebSocketService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: WebSocketService, factory: WebSocketService.ɵfac });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(WebSocketService, [{
            type: Injectable
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class ChangedDocumentService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('ChangedDocumentService');
    }
    /**
     * Listen value changes on a specified document field
     * @param fieldName the field name of document
     * @param documentId the document id
     * @param controlName the registered control that holds the field value in this component. It is used to check on the source of change
     * to avoid applying changes itself and also applying the value from the components that share the field name.
     * @param options provides more information for the watch.
     */
    watch(fieldName, documentId, controlName, options) {
        return this.ajsService.watch(fieldName, documentId, controlName, options);
    }
    /**
     * Provide the change information for the specified document field that the component binds to
     * @param component the component binds to the field
     * @param newValue the changed/new value
     * @param controlName the registered control manages the field value
     * @param options the options
     */
    valueChanged(component, value, controlName, options) {
        this.ajsService.valueChanged(component, value, controlName, options);
    }
    dispatchChanged(documentChangedInfo) {
        this.ajsService.dispatchChanged(documentChangedInfo);
    }
    executeOnFieldChangeWithNoChanges(component) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
        }
        else {
            this.ajsService.executeOnFieldChangeWithNoChanges(component);
        }
    }
    watchDocument(documentId) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
            return null;
        }
        else {
            return this.ajsService.watchDocument(documentId);
        }
    }
    watchStoreChanges() {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
            return null;
        }
        else {
            return this.ajsService.watchStoreChanges();
        }
    }
    dispatchAction(action) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
        }
        else {
            this.ajsService.dispatchAction(action);
        }
    }
    watchComponentTemplate(templateId) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.watchComponentTemplate(templateId);
        }
    }
    watchComponentDef(fieldName, templateId) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This feature is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.watchComponentDef(fieldName, templateId);
        }
    }
    notifyIntializedField(component, shouldDispatchEmptyFieldValue) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.notifyIntializedField(component, shouldDispatchEmptyFieldValue);
        }
    }
    notifyDocumentChanged(documentChangedInfo) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.notifyDocumentChanged(documentChangedInfo);
        }
    }
    notifyComponentDefinitionUpdated(templateId, fieldName, key, componentDefinition) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.notifyComponentDefinitionUpdated(templateId, fieldName, key, componentDefinition);
        }
    }
    setOrgDocument(document) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.setOrgDocument(document);
        }
    }
    setDocumentInfo(unsavedDocumentListId, docInfo) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.setDocumentInfo(unsavedDocumentListId, docInfo);
        }
    }
    setDocument(document) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.setDocument(document);
        }
    }
    setComponentFlagTemplate(templateId, fieldName, flagName, flagValue) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.setComponentFlagTemplate(templateId, fieldName, flagName, flagValue);
        }
    }
    isLoadedDocument(documentId, unsavedDocumentListId) {
        if (this.injector.isAngularJSCore()) {
            console.warn('This function is not supported on AngularJS Core.');
        }
        else {
            return this.ajsService.isLoadedDocument(documentId, unsavedDocumentListId);
        }
    }
}
ChangedDocumentService.ɵfac = function ChangedDocumentService_Factory(t) { return new (t || ChangedDocumentService)(i0.ɵɵinject(FormbirdInjectorService)); };
ChangedDocumentService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: ChangedDocumentService, factory: ChangedDocumentService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ChangedDocumentService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class FinaliseValueFieldService {
    constructor(injector) {
        this.injector = injector;
        this.ajsService = injector.get('FinaliseValueFieldService');
    }
    addFinaliseValueFunction(templateId, fieldName, func) {
        this.ajsService.addFinaliseValueFunction(templateId, fieldName, func);
    }
    getFinaliseValueFunction(templateId, fieldName) {
        return this.ajsService.getFinaliseValueFunction(templateId, fieldName);
    }
    finaliseFieldValues(document, template) {
        this.ajsService.finaliseFieldValues(document, template);
    }
}
FinaliseValueFieldService.ɵfac = function FinaliseValueFieldService_Factory(t) { return new (t || FinaliseValueFieldService)(i0.ɵɵinject(FormbirdInjectorService)); };
FinaliseValueFieldService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: FinaliseValueFieldService, factory: FinaliseValueFieldService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(FinaliseValueFieldService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class OfflineStatusService {
    constructor(formbirdInjectorService) {
        this.formbirdInjectorService = formbirdInjectorService;
        this.offlineStatusService = formbirdInjectorService.get('OfflineStatusService');
        this.offlineStatus$ = this.offlineStatusService.offlineStatus$;
        this.offlineStatus = this.offlineStatusService.offlineStatus;
        this.pageDownloadProgress = this.offlineStatusService.pageDownloadProgress;
    }
}
OfflineStatusService.ɵfac = function OfflineStatusService_Factory(t) { return new (t || OfflineStatusService)(i0.ɵɵinject(FormbirdInjectorService)); };
OfflineStatusService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: OfflineStatusService, factory: OfflineStatusService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(OfflineStatusService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class RouterService {
    constructor(injector) {
        this.injector = injector;
        this.service = injector.get('RouterService');
    }
    getActivatedRouteSnapshot() {
        return this.service.getActivatedRouteSnapshot();
    }
    navigate(params) {
        return this.service.navigate(params);
    }
    navigateByUrl(url, target) {
        return this.service.navigateByUrl(url, target);
    }
}
RouterService.ɵfac = function RouterService_Factory(t) { return new (t || RouterService)(i0.ɵɵinject(FormbirdInjectorService)); };
RouterService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: RouterService, factory: RouterService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(RouterService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class FormbirdServicesModule {
    constructor() {
    }
}
FormbirdServicesModule.ɵfac = function FormbirdServicesModule_Factory(t) { return new (t || FormbirdServicesModule)(); };
FormbirdServicesModule.ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: FormbirdServicesModule });
FormbirdServicesModule.ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
        ConfigService,
        BroadcastService,
        ClientRulesService,
        ModifiedFieldService,
        OfflineUtilService,
        OfflineStatusService,
        SearchService,
        UnsavedDocumentService,
        NotificationService,
        ModalService,
        LocationService,
        DocumentListService,
        ValidationService,
        WebSocketService,
        ChangedDocumentService,
        FinaliseValueFieldService,
        RouterService,
    ], imports: [[]] });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(FormbirdServicesModule, [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [],
                    providers: [
                        ConfigService,
                        BroadcastService,
                        ClientRulesService,
                        ModifiedFieldService,
                        OfflineUtilService,
                        OfflineStatusService,
                        SearchService,
                        UnsavedDocumentService,
                        NotificationService,
                        ModalService,
                        LocationService,
                        DocumentListService,
                        ValidationService,
                        WebSocketService,
                        ChangedDocumentService,
                        FinaliseValueFieldService,
                        RouterService,
                    ],
                    exports: []
                }]
        }], function () { return []; }, null);
})();

class DataService {
    constructor(injector) {
        this.injector = injector;
        this.dataService = injector.get('DataService');
    }
    printMessage(message, messageType, title, position, preventDuplicate, displayDesktopNotification, onClickFunction, timeOut, isPermanent) {
        return this.dataService.printMessage(message, messageType, title, position, preventDuplicate, displayDesktopNotification, onClickFunction, timeOut, isPermanent);
    }
    /*
     insert function
     parameters:
     bean - the bean to insert
     successFunction - a function to execute on success to do post save steps
     cachingRequired - whether to save the record to the local database. Records that never need
     to be loaded in the app on their own, such as events, can have this set to false
     */
    insert(bean, cachingRequired) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dataService.insert(bean, cachingRequired);
        });
    }
    /**
     * get a document
     */
    getDocument(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dataService.getDocument(id);
        });
    }
    /*
     execute component function
     parameters:
     options - object, should contin functionName, componentWebServiceName and functionParameters
     */
    executeComponentFunction(options) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dataService.executeComponentFunction(options);
        });
    }
}
DataService.ɵfac = function DataService_Factory(t) { return new (t || DataService)(i0.ɵɵinject(FormbirdInjectorService)); };
DataService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: DataService, factory: DataService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(DataService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return [{ type: FormbirdInjectorService }]; }, null);
})();

class MainDocumentListService {
    constructor() {
        const element = document.querySelectorAll('div[ui-view]');
        const injector = angular.element(element).injector();
        this.ajsService = injector.get('MainDocumentListService');
    }
    /**
     * get the main document info
     */
    getMainDocumentListId() {
        return this.ajsService.getMainDocumentInfo().documentListId;
    }
}
MainDocumentListService.ɵfac = function MainDocumentListService_Factory(t) { return new (t || MainDocumentListService)(); };
MainDocumentListService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: MainDocumentListService, factory: MainDocumentListService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(MainDocumentListService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

class DocumentService {
    constructor() { }
}
DocumentService.ɵfac = function DocumentService_Factory(t) { return new (t || DocumentService)(); };
DocumentService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: DocumentService, factory: DocumentService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(DocumentService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

class CurrentDocumentService {
    constructor() {
        const element = document.querySelectorAll('div[ui-view]');
        const injector = angular.element(element).injector();
        this.ajsService = injector.get('CurrentDocumentService');
        // get $rootScope so that observeOnScope can be called
        const rootScope = injector.get('$rootScope');
        const observeOnScope = injector.get('observeOnScope');
        // set up observable on documentData, which is a service object, similar to https://embed.plnkr.co/plunk/sGx4HH
        this.documentData$ = observeOnScope(rootScope, () => {
            return this.ajsService.documentData;
        });
    }
    /**
     * get the template from the main document - which is the document that the object nav bar is linked to
     */
    getTemplate() {
        return this.ajsService.getTemplate();
    }
    setTemplate(template) {
        return this.ajsService.setTemplate(template);
    }
    /**
     * get the document from the main document - which is the document that the object nav bar is linked to
     */
    getDocument() {
        return this.ajsService.getDocument();
    }
    setDocument(document) {
        return this.ajsService.setDocument(document);
    }
    /**
     * set showFormAfterCreated. If false, the form will not be navigated to on save
     */
    setShowFormAfterCreated(showFormAfterCreated) {
        return this.ajsService.documentData.showFormAfterCreated = showFormAfterCreated;
    }
}
CurrentDocumentService.ɵfac = function CurrentDocumentService_Factory(t) { return new (t || CurrentDocumentService)(); };
CurrentDocumentService.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: CurrentDocumentService, factory: CurrentDocumentService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(CurrentDocumentService, [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], function () { return []; }, null);
})();

'use strict';
/**
 * A constants object for constants that are used on the client-side only
 */
const ClientConstants = {
    // Used for the search filter
    FILTER: 'filter',
    FILTERED_QUERY: 'queryToBeFiltered',
    HTTP_STATUS_LOGIN_REJECTED: 401,
    OPERATION_TYPE_POST: 'POST',
    OPERATION_TYPE_PUT: 'PUT',
    OPERATION_TYPE_DELETE: 'DELETE',
    LAST_ENTERED_STATE_URL: 'LastEnteredStateUrl',
    URL_EQUAL_REPLACEMENT_STRING: 'fttf',
    // element ids
    TOGGLE_ID_LEFT: 'left_close',
    // broadcasts
    DOCUMENT_NEW: 'document:new',
    DOCUMENT_LOADED: 'document:loaded',
    DOCUMENT_LOAD_ERROR: 'document:loadError',
    VALIDATE_FORM_FIELDS: 'document:validateFormFields',
    DOCUMENT_FORM_UPDATED: 'document:formUpdated',
    PRESAVE_DOCUMENT_FORM_RESET: 'document:preSaveDocumentReset',
    URL_CLICKED: 'url:clicked',
    FORM_DIRTY_UPDATED: 'formDirty',
    SPINNER_UPDATED: 'showSpinner',
    // validation
    VALIDATION_INTERVAL_TIME: 500,
    VALIDATION_REQUIRED_KEY: 'required',
    VALIDATION_REQUIRED_MESSAGE: 'This field is required.',
    VALIDATION_MIN_LENGTH_KEY: 'hasMinLength',
    VALIDATION_MIN_LENGTH_MESSAGE: 'This field is required at least %s characters long.',
    VALIDATION_MAX_LENGTH_KEY: 'hasMaxLength',
    VALIDATION_MAX_LENGTH_MESSAGE: 'This field is required max %s characters long.',
    CHANGED_DOCUMENT_LIST_ID_KEY: '___DOCUMENT_LIST_ID___',
    FILE_SENT_EVENT_NAME: 'FileSentEventName',
    LOCAL_STORAGE_OFFLINE_STATUS_KEY: 'OfflineStatus',
    ANGULAR_COMPONENT_SUFFIX: '-ng'
};

/*
 * Public API Surface of formbird-services
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BroadcastService, ChangedDocumentService, ClientConstants, ClientRulesService, ConfigService, CurrentDocumentService, DataService, DocumentListService, DocumentService, FinaliseValueFieldService, FormbirdInjectorService, FormbirdServicesModule, LocationService, MainDocumentListService, ModalService, ModifiedFieldService, NotificationService, OfflineStatusService, OfflineUtilService, RouterService, SearchService, UnsavedDocumentService, ValidationService, WebSocketService };
//# sourceMappingURL=formbird-services.mjs.map
